<?php

/**
 * @file
 * embridge.admin.inc
 * Defines admin config. screens and functionality for the embridge module
 */

/**
 * General admin settings form for embridge.
 */
function embridge_settings() {

  // Add JS for entermedia.
  drupal_add_js(drupal_get_path('module', 'embridge') . '/js/entermedia.js');
  drupal_add_css(drupal_get_path('module', 'embridge') . '/css/entermedia.css');

  $form = array();

  // Server information.
  $form['server_info'] = array(
    '#type' => 'fieldset',
    '#title' => t('Entermedia server information'),
    '#description' => t('Information to connect to Entermedia server.'),
    '#collapsible' => TRUE,
  );
  $form['server_info']['embridge_server_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Hostname'),
    '#size' => 200,
    '#required' => TRUE,
    '#description' => t('Entermedia Hostname (e.g. http://demo.entermediasoftware.com).'),
    '#default_value' => variable_get('embridge_server_url', 'http://demo.entermediasoftware.com'),
  );
  $form['server_info']['embridge_server_port'] = array(
    '#type' => 'textfield',
    '#title' => t('Port'),
    '#size' => 7,
    '#required' => TRUE,
    '#description' => t('Entermedia server port (e.g. 8080).'),
    '#default_value' => variable_get('embridge_server_port', ''),
  );
  $form['server_info']['embridge_server_mediastore'] = array(
    '#type' => 'textfield',
    '#title' => t('Media store path'),
    '#size' => 100,
    '#required' => TRUE,
    '#description' => t('Entermedia Media store path (e.g. \\\entermedia\assets).'),
    '#default_value' => variable_get('embridge_server_mediastore', ''),
  );
  $form['server_info']['embridge_server_asset_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Asset Path Patterns'),
    '#size' => 100,
    '#description' => t('Used to create subfolders during bulk upload. Use token [dam:yyyy] for current year and [dam:mm] for current month.'),
    '#default_value' => variable_get('embridge_server_asset_path', '[dam:yyyy]/[dam:mm]'),
  );

  // User information.
  $form['user_info'] = array(
    '#type' => 'fieldset',
    '#title' => t('User information'),
    '#description' => t('Login and password for Entermedia service.'),
    '#collapsible' => TRUE,
  );
  $form['user_info']['embridge_login'] = array(
    '#type' => 'textfield',
    '#title' => t('Login'),
    '#required' => TRUE,
    '#description' => t('Login for Entermedia service.'),
    '#default_value' => variable_get('embridge_login', 'admin'),
  );
  $form['user_info']['embridge_password'] = array(
    '#type' => 'textfield',
    '#title' => t('Password'),
    '#required' => TRUE,
    '#description' => t('Password for Entermedia service.'),
    '#default_value' => variable_get('embridge_password', 'admin'),
  );

  $form['test_connection'] = array(
    '#type' => 'button',
    '#value' => t('Test Conenction'),
    '#description' => t('Click to test connection using above information.'),
  );

  // User information.
  $form['search_info'] = array(
    '#type' => 'fieldset',
    '#title' => t('Search information'),
    '#description' => t('Settings for Entermedia asset search.'),
    '#collapsible' => TRUE,
  );
  $form['search_info']['embridge_search_pagesize'] = array(
    '#type' => 'textfield',
    '#title' => t('Page Size'),
    '#description' => t('Page size for Entermedia search result.'),
    '#default_value' => variable_get('embridge_search_pagesize', 9),
  );

  $form['#validate'][] = '_embridge_settings_validate';

  embridge_catalog_settings($form);

  return system_settings_form($form);
}

/**
 * Entermedia Catalog Settings.
 */
function embridge_catalog_settings(&$form) {
  global $base_url;
  $path = drupal_get_path('module', 'embridge') . EMBRIDGE_CATALOG_CONFIG_PATH;
  $files = drupal_system_listing('/\.xml$/', $path, 'name', 0);
  $file_list = array();

  $catalogs = array();
  foreach ($files as $file) {
    $filepath = $path . '/' . $file->filename;
    $xmlobj = simplexml_load_string(file_get_contents($filepath));
    $catalog_info = (array) ($xmlobj->attributes());
    $catalog_name = $catalog_info['@attributes']['name'];
    $catalog_id = $catalog_info['@attributes']['id'];
    $catalogs[$catalog_id] = $catalog_name;

    $form[$catalog_name] = array(
      '#type' => 'fieldset',
      '#title' => $catalog_name . ' Catalog',
      '#description' => t('Search settings in @catalog_name Catalog', array('@catalog_name' => $catalog_name)),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );

    $form[$catalog_name]['urls'] = array(
      '#type' => 'item',
      '#title' => t('Search and Upload URLs'),
      'search' => array(
        '#markup' => l($base_url . '/entermedia/search/' . $catalog_name, 'entermedia/search/' . $catalog_name, array('attributes' => array('target' => '_blank'))),
      ),
      'line' => array(
        '#markup' => '<br/>',
      ),
      'upload' => array(
        '#markup' => l($base_url . '/entermedia/bulk-upload/' . $catalog_name, 'entermedia/bulk-upload/' . $catalog_name, array('attributes' => array('target' => '_blank'))),
      ),
    );

    $renditions = array();
    foreach ($xmlobj->renditions->children() as $rendition) {
      $rendition_info = ((array) $rendition);
      $renditions[$rendition_info['@attributes']['name']] = array('path' => $rendition_info[0], 'filename' => $rendition_info['@attributes']['filename']);
      $rendition_options[$rendition_info['@attributes']['name']] = $rendition_info['@attributes']['name'];
    }
    variable_set('embridge_' . drupal_strtolower($catalog_name) . '_renditions', $renditions);
    $default_renditions = variable_get('embridge_' . drupal_strtolower($catalog_name) . '_selected_renditions', array());

    $form[$catalog_name]['embridge_' . drupal_strtolower($catalog_name) . '_selected_renditions'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Renditions'),
      '#description' => t('To include renditions in Entermedia.'),
      '#options' => $rendition_options,
      '#default_value' => $default_renditions,
    );

    $fields = array();
    $field_options = array();
    foreach ($xmlobj->fields->children() as $field) {
      $field_info = ((array) $field);
      $field_options[$field_info['@attributes']['id']] = $field_info[0];
      $fields[$field_info['@attributes']['id']] = $field_info['@attributes'];
      $fields[$field_info['@attributes']['id']]['name'] = $field_info[0];
    }
    variable_set('embridge_' . drupal_strtolower($catalog_name) . '_fields', $fields);

    $form[$catalog_name]['embridge_' . drupal_strtolower($catalog_name) . '_search_fields'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Search Fields'),
      '#description' => t('To include fields in Entermedia search.'),
      '#options' => $field_options,
      '#default_value' => variable_get('embridge_' . drupal_strtolower($catalog_name) . '_search_fields', array()),
    );

    $form[$catalog_name]['embridge_' . drupal_strtolower($catalog_name) . '_result_fields'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Search Result Fields'),
      '#description' => t('To include fields in Entermedia search result.'),
      '#options' => $field_options,
      '#default_value' => variable_get('embridge_' . drupal_strtolower($catalog_name) . '_result_fields', array()),
    );
  }
  variable_set('embridge_catalogs', $catalogs);
}

/**
 * Extra validation for embridge settings.
 */
function _embridge_settings_validate($form, &$form_state) {
  // Validate URL.
  if (!valid_url($form_state['values']['embridge_server_url'], TRUE)) {
    form_set_error('embridge_server_url', t('Invalid URL.'));
  }
  // Validate Port.
  if (!is_numeric($form_state['values']['embridge_server_port'])) {
    form_set_error('embridge_server_port', t('Invalid Port.'));
  }
}

/**
 * Test connection for the Entermedia Server.
 *
 * @return String
 *   JSON indicate status of the connection.
 */
function embridge_test_connection() {
  $server_url = filter_xss($_POST['server']);
  $server_port = filter_xss($_POST['port']);
  $login = filter_xss($_POST['login']);
  $password = filter_xss($_POST['password']);
  $login_url = $server_url . ':' . $server_port . EMBRIDGE_LOGIN_PATH_DEFAULT . '?catalogid=media&accountname=' . $login . '&password=' . $password;
  watchdog('embridge', '%login_url called. ', array('%login_url' => $login_url), WATCHDOG_NOTICE);
  $xml = _embridge_curl_grab_page($server_url . ':' . $server_port . EMBRIDGE_LOGIN_PATH_DEFAULT, EMBRIDGE_QUERY_REFERER_DEFAULT, '&catalogid=media&accountname=' . $login . '&password=' . $password, 'true', 'null');
  watchdog('embridge', '%xml called. ', array('%xml' => $xml), WATCHDOG_NOTICE);
  $xml_obj = simplexml_load_string($xml);
  $xml_arr = (array) $xml_obj;
  if ($xml_arr['@attributes']['stat'] == 'ok') {
    print drupal_json_output(array('status' => t('Connected to Entermedia server successfully.')));
  }
  else {
    print drupal_json_output(array('status' => t('Failed to Entermedia server using above information.')));
  }
  exit();
}
